#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://tuxkart.sourceforge.net/
# source           : http://tuxkart.sourceforge.net/dist/tuxkart-0.4.0.tar.gz

# Package name
NAME="tuxkart"
# Package version
VERSION="0.4.0"
# Source code URL
SOURCE="http://tuxkart.sourceforge.net/dist/tuxkart-$VERSION.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS CHANGES COPYING ChangeLog INSTALL LICENSE NEWS README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: TuxKart is a 3D GoKart racing game
$NAME:
$NAME: TuxKart is a 3D GoKart racing game with several famous
$NAME: OpenSource mascots participating. The game uses PLIB and
$NAME: OpenGL, and is portable to a wide range of OS's. There are
$NAME: several racecourses provided, with full information on how
$NAME: to add your own. Except for a few minor details, this game
$NAME: is essentially complete, and very playable.
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
#	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=TuxKart
Exec=tuxkart
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Icon=tuxkart
EOF

# Create a script to launch the game - I have to or it won't launch
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/tuxkart <<EOF
#!/bin/bash

TUXKART_DATADIR=/usr/share/tuxkart /usr/share/tuxkart/tuxkart
EOF
chmod a+x $PKG/usr/bin/tuxkart

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
# Patch for not using /usr/games and /usr/share/games
sed -i -e 's,/games,,' configure
sed -i -e 's,/games,,' configure.in
sed -i -e 's,/games,,' data/Makefile.am
sed -i -e 's,/games,,' data/Makefile.in
sed -i -e 's,/games,,' fonts/Makefile.am
sed -i -e 's,/games,,' fonts/Makefile.in
sed -i -e 's,/games,,' images/Makefile.am
sed -i -e 's,/games,,' images/Makefile.in
sed -i -e 's,/games,,' models/Makefile.am
sed -i -e 's,/games,,' models/Makefile.in
sed -i -e 's,/games,,' mods/Makefile.am
sed -i -e 's,/games,,' mods/Makefile.in
sed -i -e 's,/games,,' src/start_tuxkart.cxx
sed -i -e 's,/games,,' src/tuxkart.cxx
sed -i -e 's,/games,/share/tuxkart,' src/Makefile.am
sed -i -e 's,/games,/share/tuxkart,' src/Makefile.in
sed -i -e 's,/games,,' wavs/Makefile.am
sed -i -e 's,/games,,' wavs/Makefile.in
# And then patch for not using -O6
sed -i -e 's,-O6,,' configure
sed -i -e 's,-O6,,' configure.in
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Copy icon to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $CWD/$NAME.png $PKG/usr/share/icons/hicolor/48x48/apps

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
